#
# spec file for package occt
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1600
%bcond_without docs
%else
%bcond_with    docs
%endif

%define OCCT_TAG 7_8_1

Name:           occt
Version:        7.8.1
Release:        3.1
%define soname 7_8_1
%define sover  7.8.1
%define sover_len 3
Summary:        OpenCASCADE Official Edition
License:        LGPL-2.1-only WITH OCCT-exception-1.0
Group:          Productivity/Graphics/CAD
URL:            https://www.opencascade.com/open-cascade-technology/
Source0:        https://github.com/Open-Cascade-SAS/OCCT/archive/refs/tags/V%{OCCT_TAG}.tar.gz#/occt-%{version}.tar.gz
Patch0:         https://github.com/Open-Cascade-SAS/OCCT/commit/7236e83dcc1e7284e66dc61e612154617ef715d6.patch#/fix_freetype_tag_type.patch
BuildRequires:  bison
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  tcl-devel
BuildRequires:  tk-devel
BuildRequires:  pkgconfig(RapidJSON)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xmu)
%if %{with docs}
BuildRequires:  doxygen
BuildRequires:  mathjax
%endif

%description
OpenCASCADE is a suite for 3D surface and solid modeling, visualization, data
exchange and rapid application development. It is an excellent platform for
development of numerical simulation software including CAD/CAM/CAE, AEC and
GIS, as well as PDM applications.

%package resources
Summary:        Binary resource files for %{name}
Group:          System/Libraries
BuildArch:      noarch

%description resources
This package contains resource files imported from the libraries.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Provides:       OpenCASCADE-devel = %{version}
Requires:       libopencascade-applicationframework%{soname} = %{version}
Requires:       libopencascade-dataexchange%{soname} = %{version}
Requires:       libopencascade-draw%{soname} = %{version}
Requires:       libopencascade-foundationclasses%{soname} = %{version}
Requires:       libopencascade-modelingalgorithms%{soname} = %{version}
Requires:       libopencascade-modelingdata%{soname} = %{version}
Requires:       libopencascade-visualization%{soname} = %{version}
Requires:       tcl-devel
Requires:       tk-devel
Requires:       pkgconfig(freetype2)
Requires:       pkgconfig(gl)
Requires:       pkgconfig(xext)
Requires:       pkgconfig(xmu)
Conflicts:      oce-devel

%description devel
This package contains the files needed for development with OpenCASCADE.

%package devel-doc
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
BuildArch:      noarch

%description devel-doc
Developer documentation for OpenCASCADE

%package -n libopencascade-applicationframework%{soname}
Summary:        OpenCASCADE application framework libraries
Group:          System/Libraries

%description -n libopencascade-applicationframework%{soname}
This package contains the OpenCASCADE libraries from the
OpenCASCADE application framework module:
  TKCDF TKLCAF TKCAF TKBinL TKXmlL TKBin TKXml TKStdL
  TKStd TKTObj TKBinTObj TKXmlTObj

%package -n libopencascade-dataexchange%{soname}
Summary:        OpenCASCADE data exchange libraries
Group:          System/Libraries

%description -n libopencascade-dataexchange%{soname}
This package contains the OpenCASCADE libraries from the
OpenCASCADE data exchange module:
  TKVCAF TKXSBase TKSTEPBase TKSTEPAttr TKSTEP209 TKSTEP
  TKIGES TKXCAF TKXDEIGES TKXDESTEP TKSTL TKVRML TKXmlXCAF
  TKBinXCAF TKRWMesh

%package -n libopencascade-draw%{soname}
Summary:        OpenCASCADE Draw support libraries
Group:          System/Libraries
Requires:       %{name}-resources

%description -n libopencascade-draw%{soname}
This package contains support libraries for the
OpenCASCADE DRAWEXE test harness.

%package -n libopencascade-foundationclasses%{soname}
Summary:        OpenCASCADE foundation classes libraries
Group:          System/Libraries

%description -n libopencascade-foundationclasses%{soname}
This package contains the OpenCASCADE libraries from the
OpenCASCADE foundation classes module:
  TKernel TKMath

%package -n libopencascade-modelingalgorithms%{soname}
Summary:        OpenCASCADE modeling algorithms libraries
Group:          System/Libraries

%description -n libopencascade-modelingalgorithms%{soname}
This package contains the OpenCASCADE libraries from the
OpenCASCADE modeling module:
  TKGeomAlgo TKTopAlgo TKPrim TKBO TKShHealing TKBool
  TKHLR TKFillet TKOffset TKFeat TKMesh TKXMesh

%package -n libopencascade-modelingdata%{soname}
Summary:        OpenCASCADE modeling data libraries
Group:          System/Libraries

%description -n libopencascade-modelingdata%{soname}
This package contains the OpenCASCADE libraries from the
OpenCASCADE modeling module:
  TKG2d TKG3d TKGeomBase TKBRep

%package -n libopencascade-visualization%{soname}
Summary:        OpenCASCADE visualization libraries
Group:          System/Libraries

%description -n libopencascade-visualization%{soname}
This package contains the OpenCASCADE libraries from the
OpenCASCADE visualization module:
  TKService TKV3D TKOpenGL TKMeshVS

%package DRAWEXE
Summary:        Development files for %{name}
Group:          Productivity/Graphics/CAD
Conflicts:      oce-DRAWEXE

%description DRAWEXE
This package contains the OpenCASCADE DRAWEXE test
harness executable.

%prep
%autosetup -p1 -n OCCT-%{OCCT_TAG}

%build
%cmake \
  -DCMAKE_POLICY_DEFAULT_CMP0083=NEW \
  -DBUILD_RELEASE_DISABLE_EXCEPTIONS:BOOL=false \
  -DUSE_RAPIDJSON:BOOL=true \
  -DINSTALL_DIR_LIB=%{_lib} \
  -DINSTALL_DIR_CMAKE=%{_lib}/cmake/opencascade \
  -DBUILD_SOVERSION_NUMBERS=%{sover_len} \
  ..
%cmake_build

%if %{with docs}
cd ..
./gendoc -refman -html -mathjax="%{_datadir}/javascript/mathjax"
%endif

%install
%cmake_install

# Make scripts executable
chmod 0755 %buildroot/usr/bin/*

# fixing up broken files
sed -i -e 's,'%{_lib}'\\${OCCT_INSTALL_BIN_LETTER}/,'%{_lib}'/,' %{buildroot}%{_libdir}/cmake/opencascade/*
sed -i -e 's,/lib\$,/'%{_lib}'\$,' %{buildroot}%{_libdir}/cmake/opencascade/*
grep -C5 -E "BIN_LETTER|/lib" %{buildroot}%{_libdir}/cmake/opencascade/*

rm -rf %buildroot/usr/share/doc

%fdupes %{buildroot}%{_datadir}

%post -n libopencascade-applicationframework%{soname} -p /sbin/ldconfig
%postun -n libopencascade-applicationframework%{soname} -p /sbin/ldconfig
%post -n libopencascade-dataexchange%{soname} -p /sbin/ldconfig
%postun -n libopencascade-dataexchange%{soname} -p /sbin/ldconfig
%post -n libopencascade-draw%{soname} -p /sbin/ldconfig
%postun -n libopencascade-draw%{soname} -p /sbin/ldconfig
%post -n libopencascade-foundationclasses%{soname} -p /sbin/ldconfig
%postun -n libopencascade-foundationclasses%{soname} -p /sbin/ldconfig
%post -n libopencascade-modelingalgorithms%{soname} -p /sbin/ldconfig
%postun -n libopencascade-modelingalgorithms%{soname} -p /sbin/ldconfig
%post -n libopencascade-modelingdata%{soname} -p /sbin/ldconfig
%postun -n libopencascade-modelingdata%{soname} -p /sbin/ldconfig
%post -n libopencascade-visualization%{soname} -p /sbin/ldconfig
%postun -n libopencascade-visualization%{soname} -p /sbin/ldconfig

%files -n libopencascade-applicationframework%{soname}
%_libdir/libTKBin.so.%{sover}*
%_libdir/libTKBinL.so.%{sover}*
%_libdir/libTKBinTObj.so.%{sover}*
%_libdir/libTKCAF.so.%{sover}*
%_libdir/libTKCDF.so.%{sover}*
%_libdir/libTKLCAF.so.%{sover}*
%_libdir/libTKStd.so.%{sover}*
%_libdir/libTKStdL.so.%{sover}*
%_libdir/libTKTObj.so.%{sover}*
%_libdir/libTKVCAF.so.%{sover}*
%_libdir/libTKXml.so.%{sover}*
%_libdir/libTKXmlL.so.%{sover}*
%_libdir/libTKXmlTObj.so.%{sover}*

%files -n libopencascade-dataexchange%{soname}
%_libdir/libTKBinXCAF.so.%{sover}*
%_libdir/libTKExpress.so.%{sover}*
%_libdir/libTKRWMesh.so.%{sover}*
%_libdir/libTKXCAF.so.%{sover}*
%_libdir/libTKDE.so.%{sover}*
%_libdir/libTKDECascade.so.%{sover}*
%_libdir/libTKDEGLTF.so.%{sover}*
%_libdir/libTKDEIGES.so.%{sover}*
%_libdir/libTKDEOBJ.so.%{sover}*
%_libdir/libTKDEPLY.so.%{sover}*
%_libdir/libTKDESTEP.so.%{sover}*
%_libdir/libTKDESTL.so.%{sover}*
%_libdir/libTKDEVRML.so.%{sover}*
%_libdir/libTKXSBase.so.%{sover}*
%_libdir/libTKXmlXCAF.so.%{sover}*

%files -n libopencascade-foundationclasses%{soname}
%license LICENSE_LGPL_21.txt OCCT_LGPL_EXCEPTION.txt
%_libdir/libTKernel.so.%{sover}*
%_libdir/libTKMath.so.%{sover}*

%files -n libopencascade-draw%{soname}
%_libdir/libTKDCAF.so.%{sover}*
%_libdir/libTKDraw.so.%{sover}*
%_libdir/libTKQADraw.so.%{sover}*
%_libdir/libTKTObjDRAW.so.%{sover}*
%_libdir/libTKXDEDRAW.so.%{sover}*
%_libdir/libTKXSDRAW.so.%{sover}*
%_libdir/libTKXSDRAWDE.so.%{sover}*
%_libdir/libTKXSDRAWGLTF.so.%{sover}*
%_libdir/libTKXSDRAWIGES.so.%{sover}*
%_libdir/libTKXSDRAWOBJ.so.%{sover}*
%_libdir/libTKXSDRAWPLY.so.%{sover}*
%_libdir/libTKXSDRAWSTEP.so.%{sover}*
%_libdir/libTKXSDRAWSTL.so.%{sover}*
%_libdir/libTKXSDRAWVRML.so.%{sover}*
%_libdir/libTK*Test.so.%{sover}*

%files -n libopencascade-modelingalgorithms%{soname}
%_libdir/libTKBO.so.%{sover}*
%_libdir/libTKBool.so.%{sover}*
%_libdir/libTKFeat.so.%{sover}*
%_libdir/libTKFillet.so.%{sover}*
%_libdir/libTKGeomAlgo.so.%{sover}*
%_libdir/libTKHLR.so.%{sover}*
%_libdir/libTKMesh.so.%{sover}*
%_libdir/libTKOffset.so.%{sover}*
%_libdir/libTKPrim.so.%{sover}*
%_libdir/libTKShHealing.so.%{sover}*
%_libdir/libTKTopAlgo.so.%{sover}*
%_libdir/libTKXMesh.so.%{sover}*

%files -n libopencascade-modelingdata%{soname}
%_libdir/libTKG2d.so.%{sover}*
%_libdir/libTKG3d.so.%{sover}*
%_libdir/libTKGeomBase.so.%{sover}*
%_libdir/libTKBRep.so.%{sover}*

%files -n libopencascade-visualization%{soname}
%_libdir/libTKMeshVS.so.%{sover}*
%_libdir/libTKOpenGl.so.%{sover}*
%_libdir/libTKService.so.%{sover}*
%_libdir/libTKV3d.so.%{sover}*

%files resources
%dir %{_datadir}/opencascade
%{_datadir}/opencascade/resources

%files DRAWEXE
%{_bindir}/custom*
%{_bindir}/draw.sh
%{_bindir}/env.sh
%{_bindir}/DRAWEXE*
%{_datadir}/opencascade/samples
%{_datadir}/opencascade/data

%files devel
%doc README.txt
%{_includedir}/opencascade
%dir %{_libdir}/cmake
%{_libdir}/cmake/opencascade
%{_libdir}/lib*.so
%{_bindir}/ExpToCasExe*

%if %{with docs}
%files devel-doc
%doc doc/refman/html
%endif

%changelog
* Fri Mar  7 2025 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with current freetype, add fix_freetype_tag_type.patch
* Thu Dec 19 2024 Max Lin <mlin@suse.com>
- Disable documentation build on Leap 16 for now until mathjax is
  available in Leap 16
* Wed Sep 11 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to version 7.8.1
  * Details on
    https://github.com/Open-Cascade-SAS/OCCT/releases/tag/V7_8_1
- update to version 7.8.0
  * General
    + Fixed TDataStd_NamedData HasSmth() methods to no longer
    return true for empty containers.
    + Improved general performance through code updates with static
    analysis.
    + Implemented "Memory Manager" configurations: Native, TBB,
    JeMalloc, Flexible. JeMalloc leads to a performance increase
    of up to 40%% for large files.
    + Introduced CMake configuration for optimization profiles:
    Default and Production. Production activates all available
    compiler optimizations.
    + Implemented move semantics into NCollection and TCollection
    containers.
    + Modernized NCollection_Vector(NCollection_DynamicArray),
    NCollection_Array1, and NCollection_Array2.
    + Updated memory allocation functionality to avoid unnecessary
    memory cleaning (set 0).
    + Modernized NCollection_IncAllocator (optimized pool for
    small objects).
  * Modeling
    + Addressed multiple bug fixes and improvements for various
    modeling algorithm methods.
    + Increased memory management performance.
    + Improved overall modeling stability.
    + Resolved canonical geoplane detection problems.
  * Visualization
    + Resolved compilation issues related to vtk 9.2.6.
    + Improved SelectMgr_EntityOwner to process the selection
    scheme.
    + Modified Image_AlienPixMap::Save() to write into a memory
    buffer instead of a file.
    + Reduced sensitivity of lines.
    + Extended AIS_AnimationObject with syntax for defining
    rotation around a specific point.
    + Introduced separate gesture mappings for dragging to
    AIS_ViewController.
    + Integrated the ability to scale by moving the mouse on
    the OY axis.
  * Mesh
    + Fixed BRepMesh_IncrementalMesh issue with overflowing
    system memory.
    + Unhandled Standard_OutOfRange, BRepMesh_PairOfIndex::Append()
    no longer prevents triangulation with large deflection
    values.
  * Data Exchange
    + Resolved multiple issues regarding DE Wrapper and Step import
    and export.
    + Increased STEP parser performance.
    + Introduced thread-safety interface to STEP import and export.
    + Reorganized DE ToolKits according to specific CAD formats.
    + Introduced DE plug-in system to load CAD format providers
    during library loading time.
    + Fixed stability issues with XBF and IGES file formats.
    + Addressed general problems with importing VRML V1.
    + Improved processing of STEP-oriented dimensions.
  * Draw Test Harness
    + Enabled loading of plugins on Linux OS.
    + Reorganized DRAW DE ToolKits according to specific CAD
    formats.
    + Resolved environment-related issues with debug tools
    DrawTrSurf_Set, DrawTrSurf_SetPnt, and `DrawTrSurf_SetPnt2d.
* Sun Jan  7 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use 3-digit soversion to fix BIC change between 7.7.0 and 7.7.1.
- Disable documentation build on Leap 15.x, build fails otherwise.
* Mon Jan  1 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to version 7.7.2
  * Details on
    https://git.dev.opencascade.org/gitweb/?p=occt.git;a=shortlog;h=refs/heads/OCCT-772
- update to version 7.7.1
  * Details on
    https://www.opencascade.com/open-cascade-technology-7-7-1-maintenance-release/
- Drop upstream fix_missing_limits_header.patch
* Thu Dec 29 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to version 7.7.0
  * Details on
    https://www.opencascade.com/open-cascade-technology-7-7-0-maintenance-release/
  * General
    + Improved compatibility with C++17/C++20 compilers
    + Dropped support of pre-C++11 compilers
  * Modeling
    + New functionality is implemented, which could verify the
    input shape to be placed on a canonical geometry with the
    given tolerance.
    + Introduced new tool BRepLib_PointCloudShape generating a
    point set for a topological shape.
    + New option in BRepOffsetAPI_MakeOffset - approximation of
    input contours by ones consisting of 2D circular arcs and
    2D linear segments only, it provides more stable work of
    2D offset algorithm.
  * Visualization
    + Introduced new interface for creating V3d_View as subviews
    of another V3d_View.
    + Added smoothing to row interlaced stereoscopic output.
    + Added word-wrapping option to Font_TextFormatter.
    + Added support of a wide color window buffer format (10bit
    per component / 30bit RGB).
    + Added MSAA anti-aliasing support when using WebGL 2.0.
    + Introduced skydome generation feature
    3d_View::BackgroundSkydome().
  * Mesh
    + BRepMesh works too long and produces many free nodes on a
    valid face problems are resolved.
    + Meshing the shape no longer takes too long and visualization
    problems are corrected.
    + Wrong shading display of thrusections is fixed.
    + Rendering issue when using deviation coefficient of low
    value is resolved.
    + Mesher no longer produce 'bad' result for extruded spline
    with given deviation coefficient.
    + Holes in triangulation with large linear deflection are
    removed.
    + Broken triangulation on pipe shape is fixed.
  * Data Exchange
    + STEP translator now supports tessellated presentations.
    + Transformation tools BRepBuilderAPI_Transform/
    BRepBuilderAPI_Copy now handle properly tessellated
    presentations.
    + glTF Writer - added support of Draco compression.
    + Introduced DEWrapper - a unified interface to Data
    Exchange connectors.
    + Introduced tool XCAFDoc_Editor::RescaleGeometry() for
    scaling geometry in XCAF document.
  * Configuration
    + SONAME is now configurable in CMake and includes minor
    version in addition to major by default
  * Documentation
    + Improved samples / tutorials documentation.
    + Introduced new “AIS: Custom Presentation” tutorial.
- Drop upstream patches:
  * fix_soversion_minor.patch
  + fix_build.patch
- Add fix_missing_limits_header.patch
- Library package was split up to avoid pulling in unnecessary
  indirect dependencies.
* Wed Sep  7 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to version 7.6.3
  * Details on
    https://www.opencascade.com/open-cascade-technology-7-6-3-maintenance-release/
* Mon Jul  4 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use verifiable source tarball from upstream
- Use soversion including minor version (i.e. 7_6) to avoid
  incompatibilities due to ABI changes:
  https://tracker.dev.opencascade.org/view.php?id=32856, add
  fix_soversion_minor.patch
* Fri Jul  1 2022 Adrian Schröter <adrian@suse.de>
- update to version 7.6.2
  * Details on
    https://www.opencascade.com/open-cascade-technology-7-6-2-maintenance-release/
- removed obsolete
  * 0001-0032328-Missing-include-of-TopoDS_Edge.hxx-in-ShapeU.patch
  * 0001-Add-error-checking-to-chamfer-and-fillet-code.patch
* Sun Sep  5 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build failures of FreeCAD due to a missing class definition,
  introduced with occt 7.5.2. Add
  0001-0032328-Missing-include-of-TopoDS_Edge.hxx-in-ShapeU.patch
* Wed Aug 25 2021 Adrian Schröter <adrian@suse.de>
- update to version 7.5.3A
  Modeling Algorithms maintenance fixes:
  – Wrong result of the mkface command [Minor]
  – Hang on making pipe shell using BRepOffsetAPI_MakePipeShell [Crash]
  – BRepOffsetAPI_MakePipeShell null access [Minor]
  – Empty result of offset operation in mode “Complete” join type “Intersection” [Minor]
  – General Fuse produces the wrong number of solids [Minor]
  – Empty result of offset operation in mode “Complete” Joint type “Intersection” [REGRESSION since 7.3.0]
  – Sweep crashes if Bi-normal is given [Crash]
  – Boolean fuse fails and corrupts the argument-shape [Major]
  – unify same domain calls crossed for opposite vectors [Major]
  – BOP Cut produces invalid shape [Regression]
  – Invalid result of UnifySameDomain [Major]
  – Modeling Data – Wrong result of extrema curve-surface [Major]
  Data Exchange:
  – STEP exporter generates bad geometry [REGRESSION since 7.4.0]
* Wed Aug 25 2021 Adrian Schröter <adrian@suse.de>
- update to version 7.5.3
* Mon May 10 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add disk _constraints (mostly for PPC).
* Fri Mar  5 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix cmake files, wrong install directory and lib vs lib64.
* Sat Feb 27 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- enable glTF support, depends on RapidJSON.
- Fix FreeCad crash with some fillets and chamfers
  (https://tracker.freecadweb.org/view.php?id=4543), add
  0001-Add-error-checking-to-chamfer-and-fillet-code.patch
* Mon Feb 22 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to version 7.5.1, for details see
  https://www.opencascade.com/open-cascade-starts-supporting-maintenance-releases-of-open-cascade-technology/
- update to version 7.5.0, for details see
  https://old.opencascade.com/sites/default/files/documents/release_notes_7.5.0.pdf
- update to version 7.4.0, for details see
  https://old.opencascade.com/sites/default/files/documents/release_notes_7.4.0.pdf
- Packaging changes:
  * Move resources referenced by the libraries to separate package
  * Move drawexe resources to matching package
  * Remove the mostly empty occt package
- Drop use-local-mathjax.patch, use mathjax gendoc option
- Drop enable-exceptions.patch,
  use BUILD_RELEASE_DISABLE_EXCEPTIONS=false
* Wed Nov 11 2020 Adrian Schröter <adrian@suse.de>
- update to version 7.5.0
  See for details:
  https://old.opencascade.com/sites/default/files/documents/release_notes_7.5.0.pdf
* Mon Apr 20 2020 Adrian Schröter <adrian@suse.de>
- update to version 7.4.0p1
    0031462: Modeling Algorithms - BOP result depends on the arguments order
    0031470: Modeling Algorithms - Regression: BOP common produces empty result (box and holed sphere)
    0031441: UnifySameDomain corrupts the shape
    0031415: Modeling Algorithms - Solid classifier works incorrectly on a cylinder
    0031460: Modeling Algorithms - Regression: Revolution not done.
    0031404: Modeling Algorithms - BOP Fuse produces a self-interfering or a good shape depending on the order of arguments
    0031407: [Regression to 7.3.0] Extrema does not process parallel circles correctly
    0030386: Modeling Algorithms - Unable to perform Cut operation
    0031187: Modeling Algorithms - Regression relatively 7.3.0. Unify same domain algorithm produces invalid shape.
    0031242: Scaling with different coefficients along axes produces invalid shape
    0031294: Modeling Algorithms - Regression relatively 7.3.0. Crash in method BRepPrimAPI_MakePrism::Generated(...)
    0031031: Incorrect result is returned from BRepPrimAPI_MakePrism::Generated()
    0030597: Result of BRepOffsetAPI_MakePipeShell doesn't match the given profiles
    0031153: Visualization - Non clear highlighting of selected trihedron elements
    0026071: BRepOffsetAPI_MakePipeShell produces rough result
    0031066: Infinite loop in ShapeUpgrade_UnifySameDomain
    0029843: Modeling Algorithms - Boolean FUSE produces incorrect result
* Mon Sep 30 2019 Adrian Schröter <adrian@suse.de>
- update to version 7.4.0
- enable VTK support
* Fri Mar  1 2019 Adrian Schröter <adrian@suse.de>
- update to version 7.3.0p3
  * needs to be fetch from git due to lack of tar ball
  * bugfixes:
  - 0030510: Application Framework - add missing NULL check within TDataStd_RealArray::ChangeArray()
  - 0030363: BRepLib::SameParameter with option "forced" corrupts valid shape
  - 0030174: ShapeUpgrade_UnifySameDomain does not unify cylindrical faces
  - 0030186: BRepOffsetAPI_MakePipe Generated() method produces no results for the spine edges
  - 0030204: BRepOffsetAPI_MakePipeShell crash
  - 0030354: BOP Cut doesn't modify the attached face
  - 0030143: Foundation Classes - provide operator[] alias for NCollection_Array1, NCollection_Vector
  - 0029807: [Regression to 7.0.0] Impossible to cut cone from prism
  - 0028949: BRepOffsetAPI_MakePipe Generated() method produces no result for spine edges
  - 0029573: ConcatenateWireC0 crashes on two edges wire
  - 0028085: Incorrect result of CUT operation
  - 0027928: BOP common produces empty compound
* Thu Feb  7 2019 Adrian Schröter <adrian@suse.de>
- disable the exception disablement (boo#1121972)
  (enable-exceptions.patch)
- avoid remote mathjax resource (use-local-mathjax.patch)
* Wed Jul  4 2018 adrian@suse.de
- update to version 7.3.0
  https://www.opencascade.com/sites/default/files/documents/release_notes_7.3.0.pdf
- split out documentation as noarch package
* Wed Jul  4 2018 adrian@suse.de
- fix cmake rules, OCCT_INSTALL_BIN_LETTER was not set
* Fri Sep  1 2017 adrian@suse.de
- update to version 7.2.0
* Fri Sep  1 2017 adrian@suse.de
- fix build for new glibc (don't use xlocale.h anymore)
* Thu Jul 27 2017 adrian@suse.de
- package version 7.1.0
  * Release notes are available here:
    https://www.opencascade.com/sites/default/files/documents/release_notes_7.1.0.pdf
